summaryrefslogtreecommitdiffstats
path: root/source/slang/lower.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'source/slang/lower.cpp')
-rw-r--r--source/slang/lower.cpp9
1 files changed, 7 insertions, 2 deletions
diff --git a/source/slang/lower.cpp b/source/slang/lower.cpp
index 174c93c1d..9c2c38b60 100644
--- a/source/slang/lower.cpp
+++ b/source/slang/lower.cpp
@@ -3582,9 +3582,14 @@ struct LoweringVisitor
else if (isIntegralType(varType))
{
if (info.direction == VaryingParameterDirection::Input
- && shared->entryPointRequest->profile.GetStage() == Stage::Vertex)
+ && shared->entryPointRequest->profile.GetStage() != Stage::Fragment)
{
- // Don't add extra qualification to VS inputs
+ // Don't add extra qualification to vertex shader inputs
+ }
+ else if (info.direction == VaryingParameterDirection::Output
+ && shared->entryPointRequest->profile.GetStage() == Stage::Fragment)
+ {
+ // Don't add extra qualification to fragment shader outputs
}
else
{